@@ -2,6 +2,6 @@
 # ' 
 
 BicLoc<-function(X=X,Y=Y,intercept=T,sigma=T,SumSquare=F,methode=1){
-  ret= .Call( "BicLoc", X,Y,intercept,sigma,SumSquare,methode, PACKAGE = "CorReg")
+  ret= .Call( "BicLoc_cpp", X,Y,intercept,sigma,SumSquare,methode, PACKAGE = "CorReg")
   return(ret)
 }
\ No newline at end of file
